@@ -7,14 +7,16 @@ package Vote::Count::Borda;
 
 use Moose::Role;
 
+# use Storable 3.15 qw(dclone);
+# use Try::Tiny;
 
-our $VERSION='0.021';
+our $VERSION='0.023';
 
 =head1 NAME
 
 Vote::Count::Borda
 
-=head1 VERSION 0.021
+=head1 VERSION 0.023
 
 =cut
 
@@ -28,15 +30,15 @@ use Vote::Count::RankCount;
 # use Data::Printer;
 
 has 'bordaweight' => (
-  is => 'rw',
-  isa => 'CodeRef',
+  is      => 'rw',
+  isa     => 'CodeRef',
   builder => '_buildbordaweight',
-  lazy => 1,
+  lazy    => 1,
 );
 
 has 'bordadepth' => (
-  is => 'rw',
-  isa => 'Int',
+  is      => 'rw',
+  isa     => 'Int',
   default => 0,
 );
 
@@ -44,10 +46,16 @@ has 'bordadepth' => (
 
 =head1 Synopsis
 
-  my $VC1 = Vote::Count->new(
+  my $RCV = Vote::Count->new(
     BallotSet  => read_ballots('t/data/data1.txt'),
     bordadepth => 5
   );
+  my $bordacount = $RCV->Borda();
+
+  my $RangeElection = Vote::Count->new(
+    BallotSet  => read_range_ballots('t/data/tennessee.range.json') 
+    );
+  my $scored = $RangeElection->Score();
 
 =head1 Borda Count
 
@@ -65,16 +73,9 @@ One major criticism of the count is that when there are many choices the differe
 
 Range Voting Proposals such as STAR typically use a fixed depth count where voters may rank choices equally.
 
-When Creating a VoteCount object the Borda weight
-may be set by passing a coderef. The coderef takes
-two arguments. The first argument is the
-position of the choice in question.
-The second argument is the depth of the ballot. The
-optional bordadepth attribute will set an arbitrary
-depth. Some popular options such inversion ( where
-choice $c becomes $c/1 then inverted to 1/$c) don't
-need to know the depth. In such cases the coderef
-should just ignore the second argument.
+When Creating a VoteCount object the Borda weight may be set by passing a coderef. The coderef takes two arguments. The first argument is the
+position of the choice in question. The second argument is the depth of the ballot. The optional bordadepth attribute will set an arbitrary
+depth. Some popular options such inversion (where choice $c becomes $c/1 then inverted to 1/$c) don't  need to know the depth. In such cases the coderef should just ignore the second argument.
 
   my $testweight = sub {
     my $x = int shift @_;
@@ -88,15 +89,16 @@ should just ignore the second argument.
 
 =head1 To Do
 
-Since there are so many variations of Borda, it would be nice to offer a large array of presets. Currently options are only handled by passing a coderef at object creation. Borda is not a priority for the developer, who considers Borda primarily useful as a tie breaking option or in systems like STAR that use a fixed field depth.
+Since there are so many variations of Borda, it would be nice to offer a large array of presets. Currently options are only handled by passing a coderef at object creation. Borda is not a priority for the developer, who considers Borda primarily useful as a tie breaking option or in STAR which uses a fixed field depth.
 
 =cut
 
 sub _buildbordaweight {
-   return sub {
-    my ( $x, $y ) = @_ ;
-    return ( $y +1 - $x) }
-  }
+  return sub {
+    my ( $x, $y ) = @_;
+    return ( $y + 1 - $x );
+    }
+}
 
 =pod
 
@@ -110,35 +112,35 @@ choices are removed later choices are promoted.
 
 sub _bordashrinkballot ( $BallotSet, $active ) {
   my $newballots = {};
-  my %ballots = $BallotSet->{'ballots'}->%* ;
+  my %ballots    = $BallotSet->{'ballots'}->%*;
   for my $b ( keys %ballots ) {
     my @newballot = ();
     for my $item ( $ballots{$b}{'votes'}->@* ) {
-      if ( defined $active->{ $item }) {
-        push @newballot, $item ;
+      if ( defined $active->{$item} ) {
+        push @newballot, $item;
       }
     }
-    if (scalar( @newballot )) {
+    if ( scalar(@newballot) ) {
       $newballots->{$b}{'votes'} = \@newballot;
       $newballots->{$b}{'count'} =
-    $ballots{$b}->{'count'};
+        $ballots{$b}->{'count'};
     }
   }
   return $newballots;
 }
 
-sub _dobordacount( $self, $BordaTable, $active) {
+sub _dobordacount ( $self, $BordaTable, $active ) {
   my $BordaCount = {};
-  my $weight = $self->bordaweight;
-  my $depth = $self->bordadepth
+  my $weight     = $self->bordaweight;
+  my $depth =
+      $self->bordadepth
     ? $self->bordadepth
     : scalar( keys %{$active} );
-  for my $c ( keys $BordaTable->%*) {
+  for my $c ( keys $BordaTable->%* ) {
     for my $rank ( keys $BordaTable->{$c}->%* ) {
-      $BordaCount->{ $c } = 0 unless defined $BordaCount->{ $c };
-      $BordaCount->{ $c } +=
-        $BordaTable->{$c}{$rank} *
-        $weight->( $rank, $depth ) ;
+      $BordaCount->{$c} = 0 unless defined $BordaCount->{$c};
+      $BordaCount->{$c} +=
+        $BordaTable->{$c}{$rank} * $weight->( $rank, $depth );
     }
   }
   return $BordaCount;
@@ -148,7 +150,7 @@ sub Borda ( $self, $active = undef ) {
   my %BallotSet = $self->BallotSet()->%*;
   my %ballots   = ();
   $active = $self->Active() unless defined $active;
-  %ballots = %{_bordashrinkballot( \%BallotSet, $active )};
+  %ballots = %{ _bordashrinkballot( \%BallotSet, $active ) };
   my %BordaTable = ( map { $_ => {} } keys( $active->%* ) );
   for my $b ( keys %ballots ) {
     my @votes  = $ballots{$b}->{'votes'}->@*;
@@ -163,17 +165,29 @@ sub Borda ( $self, $active = undef ) {
       }
     }
   }
-  my $BordaCounted =
-         _dobordacount(
-           $self,
-           \%BordaTable,
-           $active );
-  return Vote::Count::RankCount->Rank( $BordaCounted );
+  my $BordaCounted = _dobordacount( $self, \%BordaTable, $active );
+  return Vote::Count::RankCount->Rank($BordaCounted);
 }
 
-1;
+sub Score ( $self, $active = undef ) {
+  my $depth = $self->BallotSet()->{'depth'};
+  # my @Ballots = $self->BallotSet()->{'ballots'}->@*;
+  $active = $self->Active() unless defined $active;
+  my %scores = ( map { $_ => 0 } keys( $active->%* ) );
+  for my $ballot ( $self->BallotSet()->{'ballots'}->@* ) {
+    for my $choice ( keys %scores) {
+      if( defined $ballot->{'votes'}{$choice} ) {
+        $scores{ $choice } += $ballot->{'count'} * $ballot->{'votes'}{$choice};
+      }
+    }
+  }
+  return Vote::Count::RankCount->Rank(\%scores); 
+}
 
 
+
+1;
+
 #FOOTER
 
 =pod
@@ -195,4 +209,3 @@ LICENSE
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
 =cut
-
