@@ -12,13 +12,13 @@ use Data::Printer;
 use Vote::Count;
 use Vote::Count::ReadBallots 'read_ballots';
 
-our $VERSION='0.021';
+our $VERSION='0.023';
 
 =head1 NAME
 
 Vote::Count::Start
 
-=head1 VERSION 0.021
+=head1 VERSION 0.023
 
 =cut
 
@@ -77,7 +77,7 @@ Any other option to Vote::Count can just be passed in the arguments list
 
 =cut
 
-use Exporter::Easy ( EXPORT => [ 'StartElection' ] );
+use Exporter::Easy ( EXPORT => ['StartElection'] );
 
 # checks for ballotfile and updates the ballotset in
 # args. no return value because %ARGS is passed by reference
@@ -87,87 +87,91 @@ sub _ballotset( $ARGS ) {
     $ARGS->{'BallotSet'} = read_ballots $ARGS->{'BallotFile'};
   }
   # If
-  unless ( defined ( $ARGS->{'BallotSet'}{'choices'} )){
-    croak "A Valid BallotSet or BallotFile was not provided " . $ARGS->{'BallotFile'} ."\n";}
+  unless ( defined( $ARGS->{'BallotSet'}{'choices'} ) ) {
+    croak "A Valid BallotSet or BallotFile was not provided "
+      . $ARGS->{'BallotFile'} . "\n";
+  }
 }
 
-sub _dofloor( $self, %ARGS ) {
-  unless ( defined $ARGS{'FloorRule'}) {
+sub _dofloor ( $self, %ARGS ) {
+  unless ( defined $ARGS{'FloorRule'} ) {
     return $self->Active();
   }
-  $self->logv( ''); # log a blank line.
-  my $flr = $ARGS{'FloorRule'};
-    my $floorset = {};
-    if ( $flr eq 'TopCount') {
-      $floorset = $self->TopCountFloor( $ARGS{ 'FloorValue'} );
-    }
-    elsif ( $flr eq 'TCA') {
-      $floorset = $self->TCA();
-    }
-    elsif ( $flr eq 'Approval') {
-      $floorset = $self->ApprovalFloor( $ARGS{ 'FloorValue'} );
-    }
-    else {
-      croak "Undefined Floor rule $flr.\n";
-    }
-  $self->logv( '') ; # add blank line to output
+  $self->logv('');    # log a blank line.
+  my $flr      = $ARGS{'FloorRule'};
+  my $floorset = {};
+  if ( $flr eq 'TopCount' ) {
+    $floorset = $self->TopCountFloor( $ARGS{'FloorValue'} );
+  }
+  elsif ( $flr eq 'TCA' ) {
+    $floorset = $self->TCA();
+  }
+  elsif ( $flr eq 'Approval' ) {
+    $floorset = $self->ApprovalFloor( $ARGS{'FloorValue'} );
+  }
+  else {
+    croak "Undefined Floor rule $flr.\n";
+  }
+  $self->logv('');    # add blank line to output
   return $floorset;
 }
 
 sub _do_plurality ( $Election ) {
   my $Plurality = $Election->TopCount();
-  $Election->logv( ' ', 'Initial Top Count (Plurality)', $Plurality->RankTable() );
+  $Election->logv(
+    ' ',
+    'Initial Top Count (Plurality)',
+    $Plurality->RankTable()
+  );
   my $PluralityTop = $Plurality->Leader();
-  if ( $PluralityTop->{'winner'}) {
+  if ( $PluralityTop->{'winner'} ) {
     $Election->logt( "Plurality Winner: " . $PluralityTop->{'winner'} );
     return $PluralityTop->{'winner'};
-  } else {
+  }
+  else {
     $Election->logt(
-      "Plurality Tie: " . join( ', ', $PluralityTop->{'tied'}->@*) );
+      "Plurality Tie: " . join( ', ', $PluralityTop->{'tied'}->@* ) );
     return '';
   }
 }
 
 sub _do_approval ( $Election ) {
   my $Approval = $Election->Approval();
-  $Election->logv(
-    "\nApproval",
-    $Approval->RankTable()
-    );
+  $Election->logv( "\nApproval", $Approval->RankTable() );
   my $AWinner = $Approval->Leader();
-  if ( $AWinner->{'winner'}) {
+  if ( $AWinner->{'winner'} ) {
     $Election->logt( "Approval Winner: " . $AWinner->{'winner'} );
     return $AWinner->{'winner'};
-  } else {
+  }
+  else {
     $Election->logt(
-      "Approval Tie: " . join( ', ',  $AWinner->{'tied'}->@*) );
+      "Approval Tie: " . join( ', ', $AWinner->{'tied'}->@* ) );
     return '';
   }
 }
 
 sub _do_borda ( $Election ) {
   my $Borda = $Election->Approval();
-  $Election->logv(
-    "\Borda Count",
-    $Borda->RankTable(),
-    );
+  $Election->logv( "\Borda Count", $Borda->RankTable(), );
   my $AWinner = $Borda->Leader();
-  if ( $AWinner->{'winner'}) {
+  if ( $AWinner->{'winner'} ) {
     $Election->logt( "Borda Winner: " . $AWinner->{'winner'}, '' );
     return $AWinner->{'winner'};
-  } else {
-    $Election->logt(
-      "Borda Tie: " . join( ', ',  $AWinner->{'tied'}->@*) , '');
+  }
+  else {
+    $Election->logt( "Borda Tie: " . join( ', ', $AWinner->{'tied'}->@* ),
+      '' );
     return '';
   }
 }
 
 sub _do_majority( $Election) {
   my $majority = $Election->TopCountMajority();
-  if ($majority->{'winner'}) {
+  if ( $majority->{'winner'} ) {
     $Election->logv( "Majority Winner: " . $majority->{'winner'} );
-    return $majority->{'winner'} ;
-  } else { return '';}
+    return $majority->{'winner'};
+  }
+  else { return ''; }
 }
 
 sub _do_matrix( $Election) {
@@ -175,31 +179,29 @@ sub _do_matrix( $Election) {
   $Election->logv(
     "Pairing Results:",
     $matrix->MatrixTable(),
-    "\nSmith Set: " .
-    join( ', ', sort(keys $matrix->SmithSet()->%*) )
+    "\nSmith Set: " . join( ', ', sort( keys $matrix->SmithSet()->%* ) )
   );
   if ( $matrix->CondorcetWinner() ) {
     $Election->logv( "Condoret Winner: " . $matrix->CondorcetWinner() );
     return $matrix->CondorcetWinner();
-  } else { return ''}
+  }
+  else { return '' }
 }
 
-sub _do_irv( $Election, $floorset) {
+sub _do_irv ( $Election, $floorset ) {
   my $IRV = Vote::Count->new(
     'BallotSet' => $Election->BallotSet(),
-    'Active' => $floorset
-   );
+    'Active'    => $floorset
+  );
   my $IRVResult = try { $IRV->RunIRV() }
-    catch { croak "RunIRV exploded"};
+  catch { croak "RunIRV exploded" };
   if ( $IRVResult->{'winner'} ) {
     $Election->logt(
       'IRV (Eliminate All for Ties) Winner: ' . $IRVResult->{'winner'} );
     return $IRVResult->{'winner'};
-  } else {
-    $Election->logt(
-      'IRV Tie: ' .
-      join( ', ', $IRVResult->{'tied'}->@* )
-    );
+  }
+  else {
+    $Election->logt( 'IRV Tie: ' . join( ', ', $IRVResult->{'tied'}->@* ) );
     return '';
   }
 }
@@ -207,16 +209,16 @@ sub _do_irv( $Election, $floorset) {
 sub StartElection ( %ARGS ) {
   my $winners = {};
   _ballotset( \%ARGS );
-  my $Election = Vote::Count->new( %ARGS );
-  $winners->{'plurality'} = _do_plurality( $Election) ;
-  $winners->{'approval'}  = _do_approval(  $Election) ;
+  my $Election = Vote::Count->new(%ARGS);
+  $winners->{'plurality'} = _do_plurality($Election);
+  $winners->{'approval'}  = _do_approval($Election);
   my $floorset = _dofloor( $Election, %ARGS );
-  $Election->Active( $floorset );
-  $winners->{'majority'}  = _do_majority( $Election) ;
-  $winners->{'borda'}  = _do_borda( $Election) ;
-  $winners->{'condorcet'} = _do_matrix( $Election) ;
-  $winners->{'irv'} =  _do_irv( $Election, $floorset ) ;
-# todo generate a summary from the winners hash.
+  $Election->Active($floorset);
+  $winners->{'majority'}  = _do_majority($Election);
+  $winners->{'borda'}     = _do_borda($Election);
+  $winners->{'condorcet'} = _do_matrix($Election);
+  $winners->{'irv'}       = _do_irv( $Election, $floorset );
+  # todo generate a summary from the winners hash.
   $Election->{'startdata'} = $winners;
   return ($Election);
 }
